==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/MailAssessmentRequest.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.complex.IdentitySet;
import odata.msgraph.client.beta.enums.MailDestinationRoutingReason;
import odata.msgraph.client.beta.enums.ThreatAssessmentContentType;
import odata.msgraph.client.beta.enums.ThreatAssessmentRequestSource;
import odata.msgraph.client.beta.enums.ThreatAssessmentStatus;
import odata.msgraph.client.beta.enums.ThreatCategory;
import odata.msgraph.client.beta.enums.ThreatExpectedAssessment;

@JsonPropertyOrder({
    "@odata.type", 
    "recipientEmail", 
    "destinationRoutingReason", 
    "messageUri"})
@JsonInclude(Include.NON_NULL)
public class MailAssessmentRequest extends ThreatAssessmentRequest implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mailAssessmentRequest";
    }

    @JsonProperty("recipientEmail")
    protected String recipientEmail;

    @JsonProperty("destinationRoutingReason")
    protected MailDestinationRoutingReason destinationRoutingReason;

    @JsonProperty("messageUri")
    protected String messageUri;

    protected MailAssessmentRequest() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMailAssessmentRequest() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private OffsetDateTime createdDateTime;
        private ThreatAssessmentContentType contentType;
        private ThreatExpectedAssessment expectedAssessment;
        private ThreatCategory category;
        private ThreatAssessmentStatus status;
        private ThreatAssessmentRequestSource requestSource;
        private IdentitySet createdBy;
        private String recipientEmail;
        private MailDestinationRoutingReason destinationRoutingReason;
        private String messageUri;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder contentType(ThreatAssessmentContentType contentType) {
            this.contentType = contentType;
            this.changedFields = changedFields.add("contentType");
            return this;
        }

        public Builder expectedAssessment(ThreatExpectedAssessment expectedAssessment) {
            this.expectedAssessment = expectedAssessment;
            this.changedFields = changedFields.add("expectedAssessment");
            return this;
        }

        public Builder category(ThreatCategory category) {
            this.category = category;
            this.changedFields = changedFields.add("category");
            return this;
        }

        public Builder status(ThreatAssessmentStatus status) {
            this.status = status;
            this.changedFields = changedFields.add("status");
            return this;
        }

        public Builder requestSource(ThreatAssessmentRequestSource requestSource) {
            this.requestSource = requestSource;
            this.changedFields = changedFields.add("requestSource");
            return this;
        }

        public Builder createdBy(IdentitySet createdBy) {
            this.createdBy = createdBy;
            this.changedFields = changedFields.add("createdBy");
            return this;
        }

        public Builder recipientEmail(String recipientEmail) {
            this.recipientEmail = recipientEmail;
            this.changedFields = changedFields.add("recipientEmail");
            return this;
        }

        public Builder destinationRoutingReason(MailDestinationRoutingReason destinationRoutingReason) {
            this.destinationRoutingReason = destinationRoutingReason;
            this.changedFields = changedFields.add("destinationRoutingReason");
            return this;
        }

        public Builder messageUri(String messageUri) {
            this.messageUri = messageUri;
            this.changedFields = changedFields.add("messageUri");
            return this;
        }

        public MailAssessmentRequest build() {
            MailAssessmentRequest _x = new MailAssessmentRequest();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.mailAssessmentRequest";
            _x.id = id;
            _x.createdDateTime = createdDateTime;
            _x.contentType = contentType;
            _x.expectedAssessment = expectedAssessment;
            _x.category = category;
            _x.status = status;
            _x.requestSource = requestSource;
            _x.createdBy = createdBy;
            _x.recipientEmail = recipientEmail;
            _x.destinationRoutingReason = destinationRoutingReason;
            _x.messageUri = messageUri;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="recipientEmail")
    @JsonIgnore
    public Optional<String> getRecipientEmail() {
        return Optional.ofNullable(recipientEmail);
    }

    public MailAssessmentRequest withRecipientEmail(String recipientEmail) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("recipientEmail");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.recipientEmail = recipientEmail;
        return _x;
    }

    @Property(name="destinationRoutingReason")
    @JsonIgnore
    public Optional<MailDestinationRoutingReason> getDestinationRoutingReason() {
        return Optional.ofNullable(destinationRoutingReason);
    }

    public MailAssessmentRequest withDestinationRoutingReason(MailDestinationRoutingReason destinationRoutingReason) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("destinationRoutingReason");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.destinationRoutingReason = destinationRoutingReason;
        return _x;
    }

    @Property(name="messageUri")
    @JsonIgnore
    public Optional<String> getMessageUri() {
        return Optional.ofNullable(messageUri);
    }

    public MailAssessmentRequest withMessageUri(String messageUri) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("messageUri");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.messageUri = messageUri;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MailAssessmentRequest patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MailAssessmentRequest _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MailAssessmentRequest put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MailAssessmentRequest _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MailAssessmentRequest _copy() {
        MailAssessmentRequest _x = new MailAssessmentRequest();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.createdDateTime = createdDateTime;
        _x.contentType = contentType;
        _x.expectedAssessment = expectedAssessment;
        _x.category = category;
        _x.status = status;
        _x.requestSource = requestSource;
        _x.createdBy = createdBy;
        _x.recipientEmail = recipientEmail;
        _x.destinationRoutingReason = destinationRoutingReason;
        _x.messageUri = messageUri;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MailAssessmentRequest[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("contentType=");
        b.append(this.contentType);
        b.append(", ");
        b.append("expectedAssessment=");
        b.append(this.expectedAssessment);
        b.append(", ");
        b.append("category=");
        b.append(this.category);
        b.append(", ");
        b.append("status=");
        b.append(this.status);
        b.append(", ");
        b.append("requestSource=");
        b.append(this.requestSource);
        b.append(", ");
        b.append("createdBy=");
        b.append(this.createdBy);
        b.append(", ");
        b.append("recipientEmail=");
        b.append(this.recipientEmail);
        b.append(", ");
        b.append("destinationRoutingReason=");
        b.append(this.destinationRoutingReason);
        b.append(", ");
        b.append("messageUri=");
        b.append(this.messageUri);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/MailAssessmentRequest.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.IdentitySet;
import odata.msgraph.client.beta.enums.MailDestinationRoutingReason;
import odata.msgraph.client.beta.enums.ThreatAssessmentContentType;
import odata.msgraph.client.beta.enums.ThreatAssessmentRequestSource;
import odata.msgraph.client.beta.enums.ThreatAssessmentStatus;
import odata.msgraph.client.beta.enums.ThreatCategory;
import odata.msgraph.client.beta.enums.ThreatExpectedAssessment;

@JsonPropertyOrder({
    "@odata.type", 
    "destinationRoutingReason", 
    "messageUri", 
    "recipientEmail"})
@JsonInclude(Include.NON_NULL)
public class MailAssessmentRequest extends ThreatAssessmentRequest implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mailAssessmentRequest";
    }

    @JsonProperty("destinationRoutingReason")
    protected MailDestinationRoutingReason destinationRoutingReason;

    @JsonProperty("messageUri")
    protected String messageUri;

    @JsonProperty("recipientEmail")
    protected String recipientEmail;

    protected MailAssessmentRequest() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMailAssessmentRequest() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private ThreatCategory category;
        private ThreatAssessmentContentType contentType;
        private IdentitySet createdBy;
        private OffsetDateTime createdDateTime;
        private ThreatExpectedAssessment expectedAssessment;
        private ThreatAssessmentRequestSource requestSource;
        private ThreatAssessmentStatus status;
        private List<ThreatAssessmentResult> results;
        private MailDestinationRoutingReason destinationRoutingReason;
        private String messageUri;
        private String recipientEmail;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder category(ThreatCategory category) {
            this.category = category;
            this.changedFields = changedFields.add("category");
            return this;
        }

        public Builder contentType(ThreatAssessmentContentType contentType) {
            this.contentType = contentType;
            this.changedFields = changedFields.add("contentType");
            return this;
        }

        public Builder createdBy(IdentitySet createdBy) {
            this.createdBy = createdBy;
            this.changedFields = changedFields.add("createdBy");
            return this;
        }

        public Builder createdDateTime(OffsetDateTime createdDateTime) {
            this.createdDateTime = createdDateTime;
            this.changedFields = changedFields.add("createdDateTime");
            return this;
        }

        public Builder expectedAssessment(ThreatExpectedAssessment expectedAssessment) {
            this.expectedAssessment = expectedAssessment;
            this.changedFields = changedFields.add("expectedAssessment");
            return this;
        }

        public Builder requestSource(ThreatAssessmentRequestSource requestSource) {
            this.requestSource = requestSource;
            this.changedFields = changedFields.add("requestSource");
            return this;
        }

        public Builder status(ThreatAssessmentStatus status) {
            this.status = status;
            this.changedFields = changedFields.add("status");
            return this;
        }

        public Builder results(List<ThreatAssessmentResult> results) {
            this.results = results;
            this.changedFields = changedFields.add("results");
            return this;
        }

        public Builder results(ThreatAssessmentResult... results) {
            return results(Arrays.asList(results));
        }

        public Builder destinationRoutingReason(MailDestinationRoutingReason destinationRoutingReason) {
            this.destinationRoutingReason = destinationRoutingReason;
            this.changedFields = changedFields.add("destinationRoutingReason");
            return this;
        }

        public Builder messageUri(String messageUri) {
            this.messageUri = messageUri;
            this.changedFields = changedFields.add("messageUri");
            return this;
        }

        public Builder recipientEmail(String recipientEmail) {
            this.recipientEmail = recipientEmail;
            this.changedFields = changedFields.add("recipientEmail");
            return this;
        }

        public MailAssessmentRequest build() {
            MailAssessmentRequest _x = new MailAssessmentRequest();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.mailAssessmentRequest";
            _x.id = id;
            _x.category = category;
            _x.contentType = contentType;
            _x.createdBy = createdBy;
            _x.createdDateTime = createdDateTime;
            _x.expectedAssessment = expectedAssessment;
            _x.requestSource = requestSource;
            _x.status = status;
            _x.results = results;
            _x.destinationRoutingReason = destinationRoutingReason;
            _x.messageUri = messageUri;
            _x.recipientEmail = recipientEmail;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="destinationRoutingReason")
    @JsonIgnore
    public Optional<MailDestinationRoutingReason> getDestinationRoutingReason() {
        return Optional.ofNullable(destinationRoutingReason);
    }

    public MailAssessmentRequest withDestinationRoutingReason(MailDestinationRoutingReason destinationRoutingReason) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("destinationRoutingReason");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.destinationRoutingReason = destinationRoutingReason;
        return _x;
    }

    @Property(name="messageUri")
    @JsonIgnore
    public Optional<String> getMessageUri() {
        return Optional.ofNullable(messageUri);
    }

    public MailAssessmentRequest withMessageUri(String messageUri) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("messageUri");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.messageUri = messageUri;
        return _x;
    }

    @Property(name="recipientEmail")
    @JsonIgnore
    public Optional<String> getRecipientEmail() {
        return Optional.ofNullable(recipientEmail);
    }

    public MailAssessmentRequest withRecipientEmail(String recipientEmail) {
        MailAssessmentRequest _x = _copy();
        _x.changedFields = changedFields.add("recipientEmail");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mailAssessmentRequest");
        _x.recipientEmail = recipientEmail;
        return _x;
    }

    public MailAssessmentRequest withUnmappedField(String name, Object value) {
        MailAssessmentRequest _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MailAssessmentRequest patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        MailAssessmentRequest _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public MailAssessmentRequest put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        MailAssessmentRequest _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private MailAssessmentRequest _copy() {
        MailAssessmentRequest _x = new MailAssessmentRequest();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.category = category;
        _x.contentType = contentType;
        _x.createdBy = createdBy;
        _x.createdDateTime = createdDateTime;
        _x.expectedAssessment = expectedAssessment;
        _x.requestSource = requestSource;
        _x.status = status;
        _x.results = results;
        _x.destinationRoutingReason = destinationRoutingReason;
        _x.messageUri = messageUri;
        _x.recipientEmail = recipientEmail;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MailAssessmentRequest[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("category=");
        b.append(this.category);
        b.append(", ");
        b.append("contentType=");
        b.append(this.contentType);
        b.append(", ");
        b.append("createdBy=");
        b.append(this.createdBy);
        b.append(", ");
        b.append("createdDateTime=");
        b.append(this.createdDateTime);
        b.append(", ");
        b.append("expectedAssessment=");
        b.append(this.expectedAssessment);
        b.append(", ");
        b.append("requestSource=");
        b.append(this.requestSource);
        b.append(", ");
        b.append("status=");
        b.append(this.status);
        b.append(", ");
        b.append("results=");
        b.append(this.results);
        b.append(", ");
        b.append("destinationRoutingReason=");
        b.append(this.destinationRoutingReason);
        b.append(", ");
        b.append("messageUri=");
        b.append(this.messageUri);
        b.append(", ");
        b.append("recipientEmail=");
        b.append(this.recipientEmail);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
